import { x as CreateCollectionRequest$1, y as CreateCollectionResponse$1, z as GetCollectionRequest$1, B as GetCollectionResponse$1, H as ListCollectionsRequest$1, a as ListCollectionsResponse$1, V as UpdateCollectionRequest$1, X as UpdateCollectionResponse$1, Y as DeleteCollectionRequest$1, D as DeleteCollectionResponse$1, Z as QueryCollectionsRequest$1, a2 as QueryCollectionsResponse$1 } from './portfolio-collections-v1-collection-collections.universal-Cqne8WFQ.mjs';

interface Collection {
    /**
     * Collection ID.
     * @readonly
     * @format GUID
     */
    id?: string | null;
    /**
     * Revision number, which increments by 1 each time the collection is updated. To prevent conflicting changes, the existing revision must be passed when updating the collection object.
     * @readonly
     */
    revision?: string | null;
    /**
     * Collection title.
     * @maxLength 100
     */
    title?: string | null;
    /** Collection description. */
    description?: string | null;
    /** Collection slug. */
    slug?: string | null;
    /** Collection cover image. */
    coverImage?: Image;
    /** Whether the collection is hidden from the portfolio. Default: `false` */
    hidden?: boolean | null;
    /**
     * Index that determines which position a collection is displayed in the portfolio. <br />
     *
     * Default: [Epoch](https://www.epoch101.com/) timestamp. <br />
     */
    sortOrder?: number | null;
    /**
     * Date and time the collection was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the collection was updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Collection page URL and relative path. Returned when `includePageUrl` is `true` in the request.
     * @readonly
     */
    url?: PageUrlV2;
    /** Collection SEO data. */
    seoData?: SeoSchema;
}
interface Image {
    /** Information about the Wix Media image. */
    imageInfo?: CommonImage;
    /** Focal point of the image. */
    focalPoint?: Point;
}
interface CommonImage {
    /** WixMedia image ID. Required. */
    id?: string;
    /**
     * Image URL.
     * @readonly
     */
    url?: string;
    /** Original image height. Required. */
    height?: number;
    /** Original image width. Required. */
    width?: number;
    /** Image alt text. */
    altText?: string | null;
    /** Image filename. */
    filename?: string | null;
}
interface Point {
    /** X-coordinate of the focal point. */
    x?: number;
    /** Y-coordinate of the focal point. */
    y?: number;
}
interface PageUrlV2 {
    /** The relative path for the page within the site. For example, `/product-page/a-product`. */
    relativePath?: string;
    /** The page's full URL. For example, `https://mysite.com/product-page/a-product`. */
    url?: string | null;
}
/**
 * The SEO schema object contains data about different types of meta tags. It makes sure that the information about your page is presented properly to search engines.
 * The search engines use this information for ranking purposes, or to display snippets in the search results.
 * This data will override other sources of tags (for example patterns) and will be included in the <head> section of the HTML document, while not being displayed on the page itself.
 */
interface SeoSchema {
    /** SEO tag information. */
    tags?: Tag[];
    /** SEO general settings. */
    settings?: Settings;
}
interface Keyword {
    /** Keyword value. */
    term?: string;
    /** Whether the keyword is the main focus keyword. */
    isMain?: boolean;
    /**
     * The source that added the keyword terms to the SEO settings.
     * @maxLength 1000
     */
    origin?: string | null;
}
interface Tag {
    /**
     * SEO tag type.
     *
     *
     * Supported values: `title`, `meta`, `script`, `link`.
     */
    type?: string;
    /**
     * A `{"key": "value"}` pair object where each SEO tag property (`"name"`, `"content"`, `"rel"`, `"href"`) contains a value.
     * For example: `{"name": "description", "content": "the description itself"}`.
     */
    props?: Record<string, any> | null;
    /** SEO tag meta data. For example, `{"height": 300, "width": 240}`. */
    meta?: Record<string, any> | null;
    /** SEO tag inner content. For example, `<title> inner content </title>`. */
    children?: string;
    /** Whether the tag is a custom tag. */
    custom?: boolean;
    /** Whether the tag is disabled. */
    disabled?: boolean;
}
interface Settings {
    /**
     * Whether the Auto Redirect feature, which creates `301 redirects` on a slug change, is enabled.
     *
     *
     * Default: `false` (Auto Redirect is enabled.)
     */
    preventAutoRedirect?: boolean;
    /**
     * User-selected keyword terms for a specific page.
     * @maxSize 5
     */
    keywords?: Keyword[];
}
interface CreateCollectionRequest {
    /** Collection to create. */
    collection: Collection;
}
interface CreateCollectionResponse {
    /** Created collection. */
    collection?: Collection;
}
interface GetCollectionRequest {
    /**
     * ID of the collection to retrieve.
     * @format GUID
     */
    collectionId: string;
    /** Whether to include the collection's page URL and relative path in the response. Default: `false` */
    includePageUrl?: boolean | null;
}
interface GetCollectionResponse {
    /** The requested collection. */
    collection?: Collection;
}
interface ListCollectionsRequest {
    paging?: CursorPaging;
    /** Whether to include the collection's page URL and relative path in the response. Default: `false` */
    includePageUrl?: boolean | null;
}
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface ListCollectionsResponse {
    /** List of collections. */
    collections?: Collection[];
    /** Paging metadata. */
    metadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface UpdateCollectionRequest {
    /** Collection to update. */
    collection: Collection;
}
interface UpdateCollectionResponse {
    /** Updated collection. */
    collection?: Collection;
}
interface DeleteCollectionRequest {
    /**
     * ID of the collection to delete.
     * @format GUID
     */
    collectionId: string;
}
interface DeleteCollectionResponse {
    /**
     * ID of the deleted collection.
     * @format GUID
     */
    collectionId?: string;
}
interface QueryCollectionsRequest {
    /** Query options. */
    query: QueryV2;
    /** Whether to include the collection's page URL and relative path in the response. Default: `false` */
    includePageUrl?: boolean | null;
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /** Paging options to limit and offset the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object.
     *
     * Learn more about [filtering](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#filters).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object.
     *
     * Learn more about [sorting](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#sorting).
     */
    sort?: Sorting[];
    /** Array of projected fields. A list of specific field names to return. If `fieldsets` are also specified, the union of `fieldsets` and `fields` is returned. */
    fields?: string[];
    /** Array of named, predefined sets of projected fields. A array of predefined named sets of fields to be returned. Specifying multiple `fieldsets` will return the union of fields from all sets. If `fields` are also specified, the union of `fieldsets` and `fields` is returned. */
    fieldsets?: string[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /** Paging options to limit and offset the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface QueryCollectionsResponse {
    /** List of collections. */
    collections?: Collection[];
    /** Paging metadata. */
    metadata?: PagingMetadataV2;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createCollection(): __PublicMethodMetaInfo<'POST', {}, CreateCollectionRequest$1, CreateCollectionRequest, CreateCollectionResponse$1, CreateCollectionResponse>;
declare function getCollection(): __PublicMethodMetaInfo<'GET', {
    collectionId: string;
}, GetCollectionRequest$1, GetCollectionRequest, GetCollectionResponse$1, GetCollectionResponse>;
declare function listCollections(): __PublicMethodMetaInfo<'GET', {}, ListCollectionsRequest$1, ListCollectionsRequest, ListCollectionsResponse$1, ListCollectionsResponse>;
declare function updateCollection(): __PublicMethodMetaInfo<'PATCH', {
    collectionId: string;
}, UpdateCollectionRequest$1, UpdateCollectionRequest, UpdateCollectionResponse$1, UpdateCollectionResponse>;
declare function deleteCollection(): __PublicMethodMetaInfo<'DELETE', {
    collectionId: string;
}, DeleteCollectionRequest$1, DeleteCollectionRequest, DeleteCollectionResponse$1, DeleteCollectionResponse>;
declare function queryCollections(): __PublicMethodMetaInfo<'POST', {}, QueryCollectionsRequest$1, QueryCollectionsRequest, QueryCollectionsResponse$1, QueryCollectionsResponse>;

export { type __PublicMethodMetaInfo, createCollection, deleteCollection, getCollection, listCollections, queryCollections, updateCollection };
