// src/portfolio-collections-v1-collection-collections.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKFloatToRESTFloat } from "@wix/sdk-runtime/transformations/float";
import { transformRESTFloatToSDKFloat } from "@wix/sdk-runtime/transformations/float";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressPortfolioCollectionsCollectionsServiceUrl(opts) {
  const domainToMappings = {
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    _: [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/portfolio/v1/collections",
        destPath: "/api/v1/portfolio/collections"
      },
      {
        srcPath: "/portfolio/collections/api/v1/portfolio/collections",
        destPath: "/api/v1/portfolio/collections"
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/collections-service",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_portfolio_collections";
function createCollection(payload) {
  function __createCollection({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "collection.sortOrder" },
          { path: "collection.coverImage.focalPoint.x" },
          { path: "collection.coverImage.focalPoint.y" },
          { path: "collection.coverImage.unsharpMasking.amount" },
          { path: "collection.coverImage.unsharpMasking.radius" },
          { path: "collection.coverImage.unsharpMasking.threshold" }
        ]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "collection.createdDate" },
          { path: "collection.updatedDate" },
          { path: "collection.coverImage.imageInfo.urlExpirationDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "POST",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.CreateCollection",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collection.sortOrder" },
            { path: "collection.coverImage.focalPoint.x" },
            { path: "collection.coverImage.focalPoint.y" },
            { path: "collection.coverImage.unsharpMasking.amount" },
            { path: "collection.coverImage.unsharpMasking.radius" },
            { path: "collection.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collection.createdDate" },
            { path: "collection.updatedDate" },
            { path: "collection.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createCollection;
}
function getCollection(payload) {
  function __getCollection({ host }) {
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "GET",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.GetCollection",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections/{collectionId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collection.sortOrder" },
            { path: "collection.coverImage.focalPoint.x" },
            { path: "collection.coverImage.focalPoint.y" },
            { path: "collection.coverImage.unsharpMasking.amount" },
            { path: "collection.coverImage.unsharpMasking.radius" },
            { path: "collection.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collection.createdDate" },
            { path: "collection.updatedDate" },
            { path: "collection.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getCollection;
}
function listCollections(payload) {
  function __listCollections({ host }) {
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "GET",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.ListCollections",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collections.sortOrder" },
            { path: "collections.coverImage.focalPoint.x" },
            { path: "collections.coverImage.focalPoint.y" },
            { path: "collections.coverImage.unsharpMasking.amount" },
            { path: "collections.coverImage.unsharpMasking.radius" },
            { path: "collections.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collections.createdDate" },
            { path: "collections.updatedDate" },
            { path: "collections.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __listCollections;
}
function updateCollection(payload) {
  function __updateCollection({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "mask" }]
      },
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "collection.sortOrder" },
          { path: "collection.coverImage.focalPoint.x" },
          { path: "collection.coverImage.focalPoint.y" },
          { path: "collection.coverImage.unsharpMasking.amount" },
          { path: "collection.coverImage.unsharpMasking.radius" },
          { path: "collection.coverImage.unsharpMasking.threshold" }
        ]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "collection.createdDate" },
          { path: "collection.updatedDate" },
          { path: "collection.coverImage.imageInfo.urlExpirationDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "PATCH",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.UpdateCollection",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections/{collection.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collection.sortOrder" },
            { path: "collection.coverImage.focalPoint.x" },
            { path: "collection.coverImage.focalPoint.y" },
            { path: "collection.coverImage.unsharpMasking.amount" },
            { path: "collection.coverImage.unsharpMasking.radius" },
            { path: "collection.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collection.createdDate" },
            { path: "collection.updatedDate" },
            { path: "collection.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateCollection;
}
function deleteCollection(payload) {
  function __deleteCollection({ host }) {
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "DELETE",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.DeleteCollection",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections/{collectionId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteCollection;
}
function queryCollections(payload) {
  function __queryCollections({ host }) {
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "POST",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.QueryCollections",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections/query",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collections.sortOrder" },
            { path: "collections.coverImage.focalPoint.x" },
            { path: "collections.coverImage.focalPoint.y" },
            { path: "collections.coverImage.unsharpMasking.amount" },
            { path: "collections.coverImage.unsharpMasking.radius" },
            { path: "collections.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collections.createdDate" },
            { path: "collections.updatedDate" },
            { path: "collections.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __queryCollections;
}

// src/portfolio-collections-v1-collection-collections.meta.ts
function createCollection2() {
  const payload = {};
  const getRequestOptions = createCollection(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/api/v1/portfolio/collections",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getCollection2() {
  const payload = { collectionId: ":collectionId" };
  const getRequestOptions = getCollection(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/api/v1/portfolio/collections/{collectionId}",
    pathParams: { collectionId: "collectionId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function listCollections2() {
  const payload = {};
  const getRequestOptions = listCollections(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/api/v1/portfolio/collections",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function updateCollection2() {
  const payload = { collection: { id: ":collectionId" } };
  const getRequestOptions = updateCollection(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PATCH",
    path: "/api/v1/portfolio/collections/{collection.id}",
    pathParams: { collectionId: "collectionId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function deleteCollection2() {
  const payload = { collectionId: ":collectionId" };
  const getRequestOptions = deleteCollection(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "DELETE",
    path: "/api/v1/portfolio/collections/{collectionId}",
    pathParams: { collectionId: "collectionId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function queryCollections2() {
  const payload = {};
  const getRequestOptions = queryCollections(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/api/v1/portfolio/collections/query",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  createCollection2 as createCollection,
  deleteCollection2 as deleteCollection,
  getCollection2 as getCollection,
  listCollections2 as listCollections,
  queryCollections2 as queryCollections,
  updateCollection2 as updateCollection
};
//# sourceMappingURL=meta.mjs.map