import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { C as Collection, G as GetCollectionOptions, L as ListCollectionsOptions, a as ListCollectionsResponse, U as UpdateCollection, D as DeleteCollectionResponse, Q as QueryCollectionsOptions, b as CollectionsQueryBuilder, c as CollectionCreatedEnvelope, d as CollectionDeletedEnvelope, e as CollectionUpdatedEnvelope } from './portfolio-collections-v1-collection-collections.universal-Cqne8WFQ.js';
export { A as ActionEvent, o as AdminRemoveMenuItemsResponse, t as App, a3 as BaseEventMetadata, a5 as CollectionsQueryResult, x as CreateCollectionRequest, y as CreateCollectionResponse, J as CursorPaging, O as Cursors, w as CustomTag, Y as DeleteCollectionRequest, j as DomainEvent, k as DomainEventBodyOneOf, n as Empty, E as EntityCreatedEvent, m as EntityDeletedEvent, l as EntityUpdatedEvent, a4 as EventMetadata, F as File, z as GetCollectionRequest, B as GetCollectionResponse, p as IdentificationData, q as IdentificationDataIdOneOf, f as Image, I as ImageType, r as InvalidateCache, s as InvalidateCacheGetByOneOf, K as Keyword, H as ListCollectionsRequest, M as MessageEnvelope, u as Page, a1 as Paging, N as PagingMetadataV2, P as Point, Z as QueryCollectionsRequest, a2 as QueryCollectionsResponse, _ as QueryV2, $ as QueryV2PagingMethodOneOf, R as RestoreInfo, h as SeoSchema, i as Settings, S as SortOrder, a0 as Sorting, T as Tag, v as URI, g as UnsharpMasking, V as UpdateCollectionRequest, X as UpdateCollectionResponse, W as WebhookIdentityType } from './portfolio-collections-v1-collection-collections.universal-Cqne8WFQ.js';

declare function createCollection$1(httpClient: HttpClient): CreateCollectionSignature;
interface CreateCollectionSignature {
    /**
     * Creates a collection.
     * @param - Collection to create.
     * @returns Created collection.
     */
    (collection: Collection): Promise<Collection>;
}
declare function getCollection$1(httpClient: HttpClient): GetCollectionSignature;
interface GetCollectionSignature {
    /**
     * Retrieves a collection.
     * @param - ID of the collection to retrieve.
     * @returns The requested collection.
     */
    (collectionId: string, options?: GetCollectionOptions | undefined): Promise<Collection>;
}
declare function listCollections$1(httpClient: HttpClient): ListCollectionsSignature;
interface ListCollectionsSignature {
    /**
     * Retrieves a list all collections in a portfolio.
     */
    (options?: ListCollectionsOptions | undefined): Promise<ListCollectionsResponse>;
}
declare function updateCollection$1(httpClient: HttpClient): UpdateCollectionSignature;
interface UpdateCollectionSignature {
    /**
     * Updates a collection.
     * @param - Collection ID.
     * @returns Updated collection.
     */
    (_id: string, collection: UpdateCollection): Promise<Collection>;
}
declare function deleteCollection$1(httpClient: HttpClient): DeleteCollectionSignature;
interface DeleteCollectionSignature {
    /**
     * Deletes a collection.
     * @param - ID of the collection to delete.
     */
    (collectionId: string): Promise<DeleteCollectionResponse>;
}
declare function queryCollections$1(httpClient: HttpClient): QueryCollectionsSignature;
interface QueryCollectionsSignature {
    /**
     * Creates a query to retrieve a list of collections.
     *
     * The `queryCollections()` method builds a query to retrieve a list of collections and returns a `CollectionsQueryBuilder` object.
     *
     * The returned object contains the query definition, which is used to run the query using the [`find()`](https://dev.wix.com/docs/sdk/backend-modules/portfolio/collections/collections-query-builder/find) method.
     *
     * You can refine the query by chaining `CollectionsQueryBuilder` methods onto the query. `CollectionsQueryBuilder` methods enable you to filter, sort, and control the results that `queryCollections()` returns.
     *
     * `queryCollections()`  runs with the following `CollectionsQueryBuilder` defaults which you can override:
     *
     * + [`limit(100)`](https://dev.wix.com/docs/sdk/backend-modules/portfolio/collections/collections-query-builder/limit)
     * + [`ascending('_id')`](https://dev.wix.com/docs/sdk/backend-modules/portfolio/collections/collections-query-builder/ascending)
     *
     * The following `CollectionsQueryBuilder` methods are supported for `queryCollections()`. For a full description of the operations object, see the object returned for the [`items`](https://dev.wix.com/docs/sdk/backend-modules/portfolio/collections/collections-query-result/items) property in `CollectionsQueryResult`.
     */
    (options?: QueryCollectionsOptions | undefined): CollectionsQueryBuilder;
}
declare const onCollectionCreated$1: EventDefinition<CollectionCreatedEnvelope, "wix.portfolio.collections.v1.collection_created">;
declare const onCollectionDeleted$1: EventDefinition<CollectionDeletedEnvelope, "wix.portfolio.collections.v1.collection_deleted">;
declare const onCollectionUpdated$1: EventDefinition<CollectionUpdatedEnvelope, "wix.portfolio.collections.v1.collection_updated">;

declare const createCollection: MaybeContext<BuildRESTFunction<typeof createCollection$1> & typeof createCollection$1>;
declare const getCollection: MaybeContext<BuildRESTFunction<typeof getCollection$1> & typeof getCollection$1>;
declare const listCollections: MaybeContext<BuildRESTFunction<typeof listCollections$1> & typeof listCollections$1>;
declare const updateCollection: MaybeContext<BuildRESTFunction<typeof updateCollection$1> & typeof updateCollection$1>;
declare const deleteCollection: MaybeContext<BuildRESTFunction<typeof deleteCollection$1> & typeof deleteCollection$1>;
declare const queryCollections: MaybeContext<BuildRESTFunction<typeof queryCollections$1> & typeof queryCollections$1>;
/**
 * Triggered when a collection is created.
 */
declare const onCollectionCreated: BuildEventDefinition<typeof onCollectionCreated$1>;
/**
 * Triggered when a collection is deleted.
 */
declare const onCollectionDeleted: BuildEventDefinition<typeof onCollectionDeleted$1>;
/**
 * Triggered when a collection is updated.
 */
declare const onCollectionUpdated: BuildEventDefinition<typeof onCollectionUpdated$1>;

export { Collection, CollectionCreatedEnvelope, CollectionDeletedEnvelope, CollectionUpdatedEnvelope, CollectionsQueryBuilder, DeleteCollectionResponse, GetCollectionOptions, ListCollectionsOptions, ListCollectionsResponse, QueryCollectionsOptions, UpdateCollection, createCollection, deleteCollection, getCollection, listCollections, onCollectionCreated, onCollectionDeleted, onCollectionUpdated, queryCollections, updateCollection };
