// src/portfolio-collections-v1-collection-collections.public.ts
import { renameKeysFromRESTResponseToSDKResponse as renameKeysFromRESTResponseToSDKResponse2 } from "@wix/sdk-runtime/rename-all-nested-keys";
import { transformRESTFloatToSDKFloat as transformRESTFloatToSDKFloat2 } from "@wix/sdk-runtime/transformations/float";
import { transformRESTImageToSDKImage as transformRESTImageToSDKImage2 } from "@wix/sdk-runtime/transformations/image";
import { transformRESTPageURLV2ToSDKPageURLV2 as transformRESTPageURLV2ToSDKPageURLV22 } from "@wix/sdk-runtime/transformations/page-url-v2";
import { transformRESTTimestampToSDKTimestamp as transformRESTTimestampToSDKTimestamp2 } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths as transformPaths3 } from "@wix/sdk-runtime/transformations/transform-paths";
import { EventDefinition } from "@wix/sdk-types";

// src/portfolio-collections-v1-collection-collections.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import { queryBuilder } from "@wix/sdk-runtime/query-builder";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/portfolio-collections-v1-collection-collections.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKFloatToRESTFloat } from "@wix/sdk-runtime/transformations/float";
import { transformRESTFloatToSDKFloat } from "@wix/sdk-runtime/transformations/float";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressPortfolioCollectionsCollectionsServiceUrl(opts) {
  const domainToMappings = {
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    _: [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/collections-service",
        destPath: "/api"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/portfolio/v1/collections",
        destPath: "/api/v1/portfolio/collections"
      },
      {
        srcPath: "/portfolio/collections/api/v1/portfolio/collections",
        destPath: "/api/v1/portfolio/collections"
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/collections-service",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_portfolio_collections";
function createCollection(payload) {
  function __createCollection({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "collection.sortOrder" },
          { path: "collection.coverImage.focalPoint.x" },
          { path: "collection.coverImage.focalPoint.y" },
          { path: "collection.coverImage.unsharpMasking.amount" },
          { path: "collection.coverImage.unsharpMasking.radius" },
          { path: "collection.coverImage.unsharpMasking.threshold" }
        ]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "collection.createdDate" },
          { path: "collection.updatedDate" },
          { path: "collection.coverImage.imageInfo.urlExpirationDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "POST",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.CreateCollection",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collection.sortOrder" },
            { path: "collection.coverImage.focalPoint.x" },
            { path: "collection.coverImage.focalPoint.y" },
            { path: "collection.coverImage.unsharpMasking.amount" },
            { path: "collection.coverImage.unsharpMasking.radius" },
            { path: "collection.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collection.createdDate" },
            { path: "collection.updatedDate" },
            { path: "collection.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createCollection;
}
function getCollection(payload) {
  function __getCollection({ host }) {
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "GET",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.GetCollection",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections/{collectionId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collection.sortOrder" },
            { path: "collection.coverImage.focalPoint.x" },
            { path: "collection.coverImage.focalPoint.y" },
            { path: "collection.coverImage.unsharpMasking.amount" },
            { path: "collection.coverImage.unsharpMasking.radius" },
            { path: "collection.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collection.createdDate" },
            { path: "collection.updatedDate" },
            { path: "collection.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getCollection;
}
function listCollections(payload) {
  function __listCollections({ host }) {
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "GET",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.ListCollections",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collections.sortOrder" },
            { path: "collections.coverImage.focalPoint.x" },
            { path: "collections.coverImage.focalPoint.y" },
            { path: "collections.coverImage.unsharpMasking.amount" },
            { path: "collections.coverImage.unsharpMasking.radius" },
            { path: "collections.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collections.createdDate" },
            { path: "collections.updatedDate" },
            { path: "collections.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __listCollections;
}
function updateCollection(payload) {
  function __updateCollection({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "mask" }]
      },
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "collection.sortOrder" },
          { path: "collection.coverImage.focalPoint.x" },
          { path: "collection.coverImage.focalPoint.y" },
          { path: "collection.coverImage.unsharpMasking.amount" },
          { path: "collection.coverImage.unsharpMasking.radius" },
          { path: "collection.coverImage.unsharpMasking.threshold" }
        ]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "collection.createdDate" },
          { path: "collection.updatedDate" },
          { path: "collection.coverImage.imageInfo.urlExpirationDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "PATCH",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.UpdateCollection",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections/{collection.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collection.sortOrder" },
            { path: "collection.coverImage.focalPoint.x" },
            { path: "collection.coverImage.focalPoint.y" },
            { path: "collection.coverImage.unsharpMasking.amount" },
            { path: "collection.coverImage.unsharpMasking.radius" },
            { path: "collection.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collection.createdDate" },
            { path: "collection.updatedDate" },
            { path: "collection.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateCollection;
}
function deleteCollection(payload) {
  function __deleteCollection({ host }) {
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "DELETE",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.DeleteCollection",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections/{collectionId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteCollection;
}
function queryCollections(payload) {
  function __queryCollections({ host }) {
    const metadata = {
      entityFqdn: "wix.portfolio.collections.v1.collection",
      method: "POST",
      methodFqn: "com.wixpress.portfolio.collections.CollectionsService.QueryCollections",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPortfolioCollectionsCollectionsServiceUrl({
        protoPath: "/api/v1/portfolio/collections/query",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "collections.sortOrder" },
            { path: "collections.coverImage.focalPoint.x" },
            { path: "collections.coverImage.focalPoint.y" },
            { path: "collections.coverImage.unsharpMasking.amount" },
            { path: "collections.coverImage.unsharpMasking.radius" },
            { path: "collections.coverImage.unsharpMasking.threshold" }
          ]
        },
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "collections.createdDate" },
            { path: "collections.updatedDate" },
            { path: "collections.coverImage.imageInfo.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __queryCollections;
}

// src/portfolio-collections-v1-collection-collections.universal.ts
import { transformSDKImageToRESTImage } from "@wix/sdk-runtime/transformations/image";
import { transformRESTImageToSDKImage } from "@wix/sdk-runtime/transformations/image";
import { transformSDKPageURLV2ToRESTPageURLV2 } from "@wix/sdk-runtime/transformations/page-url-v2";
import { transformRESTPageURLV2ToSDKPageURLV2 } from "@wix/sdk-runtime/transformations/page-url-v2";
import { transformPaths as transformPaths2 } from "@wix/sdk-runtime/transformations/transform-paths";
var ImageType = /* @__PURE__ */ ((ImageType2) => {
  ImageType2["UNDEFINED"] = "UNDEFINED";
  ImageType2["WIX_MEDIA"] = "WIX_MEDIA";
  ImageType2["EXTERNAL"] = "EXTERNAL";
  return ImageType2;
})(ImageType || {});
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
var SortOrder = /* @__PURE__ */ ((SortOrder2) => {
  SortOrder2["ASC"] = "ASC";
  SortOrder2["DESC"] = "DESC";
  return SortOrder2;
})(SortOrder || {});
async function createCollection2(collection) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = transformPaths2(
    renameKeysFromSDKRequestToRESTRequest({ collection }),
    [
      {
        transformFn: transformSDKPageURLV2ToRESTPageURLV2,
        paths: [{ path: "collection.url" }]
      },
      {
        transformFn: transformSDKImageToRESTImage,
        paths: [{ path: "collection.coverImage.imageInfo" }]
      }
    ]
  );
  const reqOpts = createCollection(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTPageURLV2ToSDKPageURLV2,
          paths: [{ path: "collection.url" }]
        },
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "collection.coverImage.imageInfo" }]
        }
      ])
    )?.collection;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { collection: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["collection"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getCollection2(collectionId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    collectionId,
    includePageUrl: options?.includePageUrl
  });
  const reqOpts = getCollection(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTPageURLV2ToSDKPageURLV2,
          paths: [{ path: "collection.url" }]
        },
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "collection.coverImage.imageInfo" }]
        }
      ])
    )?.collection;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          collectionId: "$[0]",
          includePageUrl: "$[1].includePageUrl"
        },
        singleArgumentUnchanged: false
      },
      ["collectionId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function listCollections2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    paging: options?.paging,
    includePageUrl: options?.includePageUrl
  });
  const reqOpts = listCollections(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTPageURLV2ToSDKPageURLV2,
          paths: [{ path: "collections.url" }]
        },
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "collections.coverImage.imageInfo" }]
        }
      ])
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          paging: "$[0].paging",
          includePageUrl: "$[0].includePageUrl"
        },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function updateCollection2(_id, collection) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = transformPaths2(
    renameKeysFromSDKRequestToRESTRequest({
      collection: { ...collection, id: _id }
    }),
    [
      {
        transformFn: transformSDKPageURLV2ToRESTPageURLV2,
        paths: [{ path: "collection.url" }]
      },
      {
        transformFn: transformSDKImageToRESTImage,
        paths: [{ path: "collection.coverImage.imageInfo" }]
      }
    ]
  );
  const reqOpts = updateCollection(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTPageURLV2ToSDKPageURLV2,
          paths: [{ path: "collection.url" }]
        },
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "collection.coverImage.imageInfo" }]
        }
      ])
    )?.collection;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: { collection: "$[1]" },
        explicitPathsToArguments: { "collection.id": "$[0]" },
        singleArgumentUnchanged: false
      },
      ["_id", "collection"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function deleteCollection2(collectionId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    collectionId
  });
  const reqOpts = deleteCollection(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { collectionId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["collectionId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
function queryCollections2(options) {
  const { httpClient, sideEffects } = arguments[1];
  return queryBuilder({
    func: async (payload) => {
      const reqOpts = queryCollections({
        ...payload,
        ...options ?? {}
      });
      sideEffects?.onSiteCall?.();
      try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return result;
      } catch (err) {
        sideEffects?.onError?.(err);
        throw err;
      }
    },
    requestTransformer: (query) => {
      const args = [query, options];
      return renameKeysFromSDKRequestToRESTRequest({
        ...args?.[1],
        query: args?.[0]
      });
    },
    responseTransformer: ({ data }) => {
      const transformedData = renameKeysFromRESTResponseToSDKResponse(
        transformPaths2(data, [
          {
            transformFn: transformRESTPageURLV2ToSDKPageURLV2,
            paths: [{ path: "collections.url" }]
          },
          {
            transformFn: transformRESTImageToSDKImage,
            paths: [{ path: "collections.coverImage.imageInfo" }]
          }
        ])
      );
      return {
        items: transformedData?.collections,
        pagingMetadata: transformedData?.metadata
      };
    },
    errorTransformer: (err) => {
      const transformedError = sdkTransformError(err, {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { query: "$[0]" },
        singleArgumentUnchanged: false
      });
      throw transformedError;
    },
    pagingMethod: "CURSOR",
    transformationPaths: {}
  });
}

// src/portfolio-collections-v1-collection-collections.public.ts
function createCollection3(httpClient) {
  return (collection) => createCollection2(
    collection,
    // @ts-ignore
    { httpClient }
  );
}
function getCollection3(httpClient) {
  return (collectionId, options) => getCollection2(
    collectionId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function listCollections3(httpClient) {
  return (options) => listCollections2(
    options,
    // @ts-ignore
    { httpClient }
  );
}
function updateCollection3(httpClient) {
  return (_id, collection) => updateCollection2(
    _id,
    collection,
    // @ts-ignore
    { httpClient }
  );
}
function deleteCollection3(httpClient) {
  return (collectionId) => deleteCollection2(
    collectionId,
    // @ts-ignore
    { httpClient }
  );
}
function queryCollections3(httpClient) {
  return (options) => queryCollections2(
    options,
    // @ts-ignore
    { httpClient }
  );
}
var onCollectionCreated = EventDefinition(
  "wix.portfolio.collections.v1.collection_created",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          { path: "entity.sortOrder" },
          { path: "entity.coverImage.focalPoint.x" },
          { path: "entity.coverImage.focalPoint.y" },
          { path: "entity.coverImage.unsharpMasking.amount" },
          { path: "entity.coverImage.unsharpMasking.radius" },
          { path: "entity.coverImage.unsharpMasking.threshold" }
        ]
      },
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "entity.createdDate" },
          { path: "entity.updatedDate" },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTPageURLV2ToSDKPageURLV22,
        paths: [{ path: "entity.url" }]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [{ path: "entity.coverImage.imageInfo" }]
      }
    ])
  )
)();
var onCollectionDeleted = EventDefinition(
  "wix.portfolio.collections.v1.collection_deleted",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          { path: "undefined.sortOrder" },
          { path: "undefined.coverImage.focalPoint.x" },
          { path: "undefined.coverImage.focalPoint.y" },
          { path: "undefined.coverImage.unsharpMasking.amount" },
          { path: "undefined.coverImage.unsharpMasking.radius" },
          { path: "undefined.coverImage.unsharpMasking.threshold" }
        ]
      },
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "undefined.createdDate" },
          { path: "undefined.updatedDate" },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTPageURLV2ToSDKPageURLV22,
        paths: [{ path: "undefined.url" }]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [{ path: "undefined.coverImage.imageInfo" }]
      }
    ])
  )
)();
var onCollectionUpdated = EventDefinition(
  "wix.portfolio.collections.v1.collection_updated",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          { path: "entity.sortOrder" },
          { path: "entity.coverImage.focalPoint.x" },
          { path: "entity.coverImage.focalPoint.y" },
          { path: "entity.coverImage.unsharpMasking.amount" },
          { path: "entity.coverImage.unsharpMasking.radius" },
          { path: "entity.coverImage.unsharpMasking.threshold" }
        ]
      },
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "entity.createdDate" },
          { path: "entity.updatedDate" },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTPageURLV2ToSDKPageURLV22,
        paths: [{ path: "entity.url" }]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [{ path: "entity.coverImage.imageInfo" }]
      }
    ])
  )
)();

// src/portfolio-collections-v1-collection-collections.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
import { createEventModule } from "@wix/sdk-runtime/event-definition-modules";
var createCollection4 = /* @__PURE__ */ createRESTModule(createCollection3);
var getCollection4 = /* @__PURE__ */ createRESTModule(getCollection3);
var listCollections4 = /* @__PURE__ */ createRESTModule(listCollections3);
var updateCollection4 = /* @__PURE__ */ createRESTModule(updateCollection3);
var deleteCollection4 = /* @__PURE__ */ createRESTModule(deleteCollection3);
var queryCollections4 = /* @__PURE__ */ createRESTModule(queryCollections3);
var onCollectionCreated2 = createEventModule(onCollectionCreated);
var onCollectionDeleted2 = createEventModule(onCollectionDeleted);
var onCollectionUpdated2 = createEventModule(onCollectionUpdated);
export {
  ImageType,
  SortOrder,
  WebhookIdentityType,
  createCollection4 as createCollection,
  deleteCollection4 as deleteCollection,
  getCollection4 as getCollection,
  listCollections4 as listCollections,
  onCollectionCreated2 as onCollectionCreated,
  onCollectionDeleted2 as onCollectionDeleted,
  onCollectionUpdated2 as onCollectionUpdated,
  queryCollections4 as queryCollections,
  updateCollection4 as updateCollection
};
//# sourceMappingURL=index.mjs.map